==> refcomp-entities-1.6-sources.jar: fr/inra/refcomp/entities/UnitDeptLink.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface UnitDeptLink extends BusinessEntity {

    String EXT_UNITDEPTLINK = "UnitDeptLink";

    String FIELD_UNITDEPTLINK_UNIT = "unit";

    String FQ_FIELD_UNITDEPTLINK_UNIT = EXT_UNITDEPTLINK + ".unit";

    ElementField ELEMENT_FIELD_UNITDEPTLINK_UNIT = new ElementField(FQ_FIELD_UNITDEPTLINK_UNIT);

    String FIELD_UNITDEPTLINK_DEPARTMENT = "department";

    String FQ_FIELD_UNITDEPTLINK_DEPARTMENT = EXT_UNITDEPTLINK + ".department";

    ElementField ELEMENT_FIELD_UNITDEPTLINK_DEPARTMENT = new ElementField(FQ_FIELD_UNITDEPTLINK_DEPARTMENT);

    String getUnit();

    void setUnit(String unit);

    String getDepartment();

    void setDepartment(String department);

} //UnitDeptLink

==> refcomp-entities-1.7-sources.jar: fr/inra/refcomp/entities/UnitDeptLink.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.ElementField;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public interface UnitDeptLink extends BusinessEntity {

    String EXT_UNITDEPTLINK = "UnitDeptLink";

    String FIELD_UNITDEPTLINK_UNIT = "unit";

    String FQ_FIELD_UNITDEPTLINK_UNIT = EXT_UNITDEPTLINK + ".unit";

    ElementField ELEMENT_FIELD_UNITDEPTLINK_UNIT = new ElementField(FQ_FIELD_UNITDEPTLINK_UNIT);

    String FIELD_UNITDEPTLINK_DEPARTMENT = "department";

    String FQ_FIELD_UNITDEPTLINK_DEPARTMENT = EXT_UNITDEPTLINK + ".department";

    ElementField ELEMENT_FIELD_UNITDEPTLINK_DEPARTMENT = new ElementField(FQ_FIELD_UNITDEPTLINK_DEPARTMENT);

    String getUnit();

    void setUnit(String unit);

    Unit getUnit(boolean exceptionIfNotLoaded);

    void setUnit(Unit unit);

    String getDepartment();

    void setDepartment(String department);

    Department getDepartment(boolean exceptionIfNotLoaded);

    void setDepartment(Department department);

} //UnitDeptLink
